@@ -14,11 +14,9 @@
 # limitations under the License.
 
 import collections
-import logging
 
 from glanceclient import exc as exceptions
-
-LOG = logging.getLogger(__name__)
+from glanceclient.v2.client import Client as real_glance_client
 
 
 def create_or_find_kernel_and_ramdisk(glanceclient, kernel_name, ramdisk_name,
@@ -50,7 +48,23 @@ def _upload_file(glanceclient, name, path, disk_format, type_name,
                  skip_missing=False):
     image_tuple = collections.namedtuple('image', ['id'])
     try:
-        image = glanceclient.images.find(name=name, disk_format=disk_format)
+        if isinstance(glanceclient, real_glance_client):
+            images = glanceclient.images.list(name=name,
+                                              disk_format=disk_format)
+            image = None
+            for img in images:
+                if img['name'] == name and img['disk_format'] == disk_format:
+                    image = img
+            if not image:
+                raise exceptions.NotFound("No image found")
+        else:
+            # TODO(dprince) remove this
+            # This code expects the python-openstackclient version of
+            # "glanceclient" (which isn't pure python-glanceclient) and is
+            # here for backwards compat until python-tripleoclient starts
+            # using the Mistral API for this functionality.
+            image = glanceclient.images.find(name=name,
+                                             disk_format=disk_format)
     except exceptions.NotFound:
         if path:
             image = glanceclient.images.create(
